@@ -1,11 +1,11 @@
 from django.db import models
 from django.contrib.contenttypes import generic
 from django.contrib.contenttypes.models import ContentType
-
-from ..mixins import EventMixin
+from django.utils.encoding import python_2_unicode_compatible
 
 
-class Event(models.Model, EventMixin):
+@python_2_unicode_compatible
+class Event(models.Model):
     object_id = models.PositiveIntegerField()
     content_object = generic.GenericForeignKey('content_type', 'object_id')
 
@@ -15,3 +15,6 @@ class Event(models.Model, EventMixin):
 
     class Meta:
         db_table = 'simple_events_event'
+
+    def __str__(self):
+        return u'%s for %s' % (self.name, self.content_object)
